@@ -38,9 +38,19 @@ ipp_t *gnome_cups_request_execute                  (ipp_t       *request,
 						    const char  *server,
 						    const char  *path,
 						    GError     **err);
-guint gnome_cups_request_execute_async             (ipp_t       *request,
-						    const char *server,
+void  gnome_cups_request_file			   (const char  *server,
 						    const char  *path,
+						    int fd,
+						    GError     **err);
+guint gnome_cups_request_execute_async             (ipp_t       *request,
+						    const char  *server,
+						    const char  *path,
+						    GnomeCupsAsyncRequestCallback callback,
+						    gpointer cb_data,
+						    GDestroyNotify destroy_notify);
+guint gnome_cups_request_file_async                (const char  *server,
+						    const char  *path,
+						    int outfile_fd,
 						    GnomeCupsAsyncRequestCallback callback,
 						    gpointer cb_data,
 						    GDestroyNotify destroy_notify);
